@@ -3,14 +3,17 @@ from .copy_message import copy_message
 from .delete_message import delete_message
 from .delete_my_commands import delete_my_commands
 from .edit_message_caption import edit_message_caption
+from .edit_message_reply_markup import edit_message_reply_markup
 from .edit_message_text import edit_message_text
+from .get_chat import get_chat
 from .get_chat_member import get_chat_member
 from .get_file import get_file, get_file_url
 from .get_me import get_me
+from .send_animation import send_animation
+from .send_audio import send_audio
 from .send_chat_action import send_chat_action
 from .send_media_group import send_media_group
 from .send_message import send_message
 from .send_photo import send_photo
 from .send_video import send_video
 from .set_my_commands import set_my_commands
-from .get_chat import get_chat
